ObjectType

Enum ObjectType 

pub enum ObjectType {
    Activity,
    Agent,
    Group,
    SubStatement,
    StatementRef,
    ContextAgent,
    ContextGroup,
    Person,
}
Objects (Activity, Agent, Group, StatementRef, etc…) in xAPI vary widely in use and can share similar properties making it hard, and sometimes impossible, to know or decide which type is meant except for the presence of a variant of this enumeration in those objects’ JSON representation.

Variants



Activity

Data is part of an Activity.



Agent

Data is part of an Agent.



Group

Data is part of a Group.



SubStatement

Data is part of a Sub-Statement.



StatementRef

Data is part of a Statement-Reference.



ContextAgent

Data is part of an Context Agent.



ContextGroup

Data is part of an Context Group.



Person

Data is part of a Person.