pub enum SubStatementObject {
Agent(Agent),
Group(Group),
StatementRef(StatementRef),
Activity(Activity),
}Expand description
Enumeration for a potential Object of a Statement itself being the Object of another; i.e. the designated variant here is the Object of the Statement referenced in a sub-statement variant.
Variants
Agent(Agent)
The object is an Agent.
Group(Group)
The object is a Group.
StatementRef(StatementRef)
The object is a Statement-Reference.
Activity(Activity)
The object is an Activity.
Implementations
Sourceimpl SubStatementObject
impl SubStatementObject
Sourcepub fn from_agent(obj: Agent) -> Self
pub fn from_agent(obj: Agent) -> Self
Coerce an Agent to a SubStatementObject.
Sourcepub fn from_group(obj: Group) -> Self
pub fn from_group(obj: Group) -> Self
Coerce a Group to a SubStatementObject.
Sourcepub fn from_statement_ref(obj: StatementRef) -> Self
pub fn from_statement_ref(obj: StatementRef) -> Self
Coerce a StatementRef to a SubStatementObject.
Sourcepub fn from_activity(obj: Activity) -> Self
pub fn from_activity(obj: Activity) -> Self
Coerce an Activity to a SubStatementObject.
Sourcepub fn is_statement_ref(&self) -> bool
pub fn is_statement_ref(&self) -> bool
Return TRUE if this is an StatementRef variant; FALSE otherwise.
Sourcepub fn is_activity(&self) -> bool
pub fn is_activity(&self) -> bool
Return TRUE if this is an Activity variant; FALSE otherwise.
Sourcepub fn as_statement_ref(&self) -> Result<StatementRef, DataError>
pub fn as_statement_ref(&self) -> Result<StatementRef, DataError>
Coerce this to a StatementRef if indeed it was an SubStatementObject::StatementRef
variant. Raise DataError if it was not.