pub enum Vocabulary {
Show 18 variants
Answered,
Asked,
Attempted,
Attended,
Commented,
Exited,
Experienced,
Imported,
Interacted,
Launched,
Mastered,
Preferred,
Progressed,
Registered,
Shared,
Voided,
LoggedIn,
LoggedOut,
}Expand description
Enumeration of ADL1 Verbs referenced in xAPI.
Advanced Distributed Learning (https://adlnet.gov/). ↩
Variants
Answered
Indicates the actor replied to a question, where the object is generally an activity representing the question. The text of the answer will often be included in the response inside result.
Asked
Indicates an inquiry by an actor with the expectation of a response or answer to a question.
Attempted
Indicates the actor made an effort to access the object. An attempt statement without additional activities could be considered incomplete in some cases.
Attended
Indicates the actor was present at a virtual or physical event or activity.
Commented
Indicates the actor provided digital or written annotations on or about an object.
Exited
Indicates the actor intentionally departed from the activity or object.
Experienced
Indicates the actor only encountered the object, and is applicable in situations where a specific achievement or completion is not required.
Imported
Indicates the actor introduced an object into a physical or virtual location.
Interacted
Indicates the actor engaged with a physical or virtual object.
Launched
Indicates the actor attempted to start an activity.
Mastered
Indicates the highest level of comprehension or competence the actor performed in an activity.
Preferred
Indicates the selected choices, favored options or settings of an actor in relation to an object or activity.
Progressed
Indicates a value of how much of an actor has advanced or moved through an activity.
Registered
Indicates the actor is officially enrolled or inducted in an activity.
Indicates the actor’s intent to openly provide access to an object of common interest to other actors or groups.
Voided
A special reserved verb used by a LRS or application to mark a statement as invalid. See the xAPI specification for details on Voided statements.
LoggedIn
Indicates the actor gained access to a system or service by identifying and authenticating with the credentials provided by the actor.
LoggedOut
Indicates the actor either lost or discontinued access to a system or service.