pub struct AccountBuilder<'a> { /* private fields */ }Expand description
A Type that knows how to construct an Account.
Implementations
Sourceimpl<'a> AccountBuilder<'a>
impl<'a> AccountBuilder<'a>
Sourcepub fn home_page(self, val: &'a str) -> Result<Self, DataError>
pub fn home_page(self, val: &'a str) -> Result<Self, DataError>
Set the home_page field.
Raise DataError if the argument is empty, cannot be parsed as an IRI, or the resulting IRI is not a valid URL.