Activity

Struct Activity 

pub struct Activity { /* private fields */ }
Structure making up “this” in “I did this”; it is something with which an Actor interacted. It can be a unit of instruction, experience, or performance that is to be tracked in meaningful combination with a Verb.

Interpretation of Activity is broad, meaning that activities can even be tangible objects such as a chair (real or virtual). In the Statement “Anna tried a cake recipe”, the recipe constitutes the Activity. Other examples may include a book, an e-learning course, a hike, or a meeting.

Implementations

Source

impl Activity

pub fn from_iri_str(iri: &str) -> Result<Self, DataError>

Constructor that creates a new empty instance when it successfully parses the input as the Activity’s IRI identifier.

pub fn builder() -> ActivityBuilder<'static>

Return an Activity Builder.

pub fn id(&self) -> &IriStr

Return id field as an IRI.

pub fn id_as_str(&self) -> &str

Return id field as a string reference.

pub fn definition(&self) -> Option<&ActivityDefinition>

Return definition field if set; None otherwise.

pub fn merge(&mut self, other: Activity)

Consumes other’s definition replacing or augmenting self’s.

pub fn name(&self, tag: &MyLanguageTag) -> Option<&str>

Convenience pass-through method to the definition field. Return name for the given language tag if it exists; None otherwise.

pub fn description(&self, tag: &MyLanguageTag) -> Option<&str>

Convenience pass-through method to the definition field. Return description for the given language tag if it exists; None otherwise.

pub fn type_(&self) -> Option<&IriStr>

Convenience pass-through method to the definition field. Return type_ if set; None otherwise.

pub fn more_info(&self) -> Option<&IriStr>

Convenience pass-through method to the definition field. Return more_info if set; None otherwise.

When set, it’s an IRL that points to information about the associated Activity possibly incl. a way to launch it.

pub fn interaction_type(&self) -> Option<&InteractionType>

Convenience pass-through method to the definition field. Return interaction_type if set; None otherwise.

Possible values are: true-false, choice, fill-in, long-fill-in, matching, performance, sequencing, likert, numeric, and other,

pub fn correct_responses_pattern(&self) -> Option<&Vec<String>>

Convenience pass-through method to the definition field. Return correct_responses_pattern if set; None otherwise.

When set, it’s a Vector of patterns representing the correct response to the interaction.

The structure of the patterns vary depending on the interaction_type.

pub fn choices(&self) -> Option<&Vec<InteractionComponent>>

Convenience pass-through method to the definition field. Return choices if set; None otherwise.

When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.

The contents of item(s) in the vector are specific to the given interaction type.

pub fn scale(&self) -> Option<&Vec<InteractionComponent>>

Convenience pass-through method to the definition field. Return scale if set; None otherwise.

When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.

The contents of item(s) in the vector are specific to the given interaction type.

pub fn source(&self) -> Option<&Vec<InteractionComponent>>

Convenience pass-through method to the definition field. Return source if set; None otherwise.

When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.

The contents of item(s) in the vector are specific to the given interaction type.

pub fn target(&self) -> Option<&Vec<InteractionComponent>>

Convenience pass-through method to the definition field. Return target if set; None otherwise.

When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.

The contents of item(s) in the vector are specific to the given interaction type.

pub fn steps(&self) -> Option<&Vec<InteractionComponent>>

Convenience pass-through method to the definition field. Return steps if set; None otherwise.

When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.

The contents of item(s) in the vector are specific to the given interaction type.

pub fn extensions(&self) -> Option<&Extensions>

Convenience pass-through method to the definition field. Return Extensions if set; None otherwise.

pub fn extension(&self, key: &IriStr) -> Option<&Value>

Convenience pass-through method to the definition field. Return extension keyed by key if it exists; None otherwise.

pub fn set_object_type(&mut self)

Ensure object_type field is set.