ActivityDefinition

Struct ActivityDefinition 

pub struct ActivityDefinition { /* private fields */ }
Structure that provides additional information (metadata) related to an Activity.

Implementations

Source

impl ActivityDefinition

pub fn builder() -> ActivityDefinitionBuilder<'static>

Return an ActivityDefinition Builder.

pub fn name(&self, tag: &MyLanguageTag) -> Option<&str>

Return the name for the given language tag if it exists; None otherwise.

pub fn description(&self, tag: &MyLanguageTag) -> Option<&str>

Return the description for the given language tag if it exists; None otherwise.

pub fn type_(&self) -> Option<&IriStr>

Return the type_ field if set; None otherwise.

pub fn more_info(&self) -> Option<&IriStr>

Return the more_info field if set; None otherwise.

When set, it’s an IRL that points to information about the associated Activity possibly incl. a way to launch it.

pub fn interaction_type(&self) -> Option<&InteractionType>

Return the interaction_type field if set; None otherwise.

Possible values are: true-false, choice, fill-in, long-fill-in, matching, performance, sequencing, likert, numeric, and other,

pub fn correct_responses_pattern(&self) -> Option<&Vec<String>>

Return the correct_responses_pattern field if set; None otherwise.

When set, it’s a Vector of patterns representing the correct response to the interaction.

The structure of the patterns vary depending on the interaction_type.

pub fn choices(&self) -> Option<&Vec<InteractionComponent>>

Return the choices field if set; None otherwise.

When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.

The contents of item(s) in the vector are specific to the given interaction_type.

pub fn scale(&self) -> Option<&Vec<InteractionComponent>>

Return the scale field if set; None otherwise.

When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.

The contents of item(s) in the vector are specific to the given interaction_type.

pub fn source(&self) -> Option<&Vec<InteractionComponent>>

Return the source field if set; None otherwise.

When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.

The contents of item(s) in the vector are specific to the given interaction_type.

pub fn target(&self) -> Option<&Vec<InteractionComponent>>

Return the target field if set; None otherwise.

When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.

The contents of item(s) in the vector are specific to the given interaction_type.

pub fn steps(&self) -> Option<&Vec<InteractionComponent>>

Return the steps field if set; None otherwise.

When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.

The contents of item(s) in the vector are specific to the given interaction_type.

pub fn extensions(&self) -> Option<&Extensions>

Return the extensions field if set; None otherwise.

pub fn extension(&self, key: &IriStr) -> Option<&Value>

Return the extension keyed by key if it exists; None otherwise.

pub fn merge(&mut self, that: Self)

Consume that merging it into this instance.