pub struct Agent { /* private fields */ }Expand description
Structure that provides combined information about an individual derived from an outside service, such as a Directory Service.
Implementations
Sourceimpl Agent
impl Agent
Sourcepub fn from_json_obj(map: Map<String, Value>) -> Result<Self, DataError>
pub fn from_json_obj(map: Map<String, Value>) -> Result<Self, DataError>
Construct and validate an Agent from a JSON Object.
Sourcepub fn builder() -> AgentBuilder
pub fn builder() -> AgentBuilder
Return an Agent Builder.
Sourcepub fn check_object_type(&self) -> bool
pub fn check_object_type(&self) -> bool
Return TRUE if the objectType property is as expected; FALSE otherwise.
Sourcepub fn name_as_str(&self) -> Option<&str>
pub fn name_as_str(&self) -> Option<&str>
Return name as a string reference if set; None otherwise.
Sourcepub fn mbox(&self) -> Option<&MyEmailAddress>
pub fn mbox(&self) -> Option<&MyEmailAddress>
Return mbox as an MyEmailAddress if set; None otherwise.
Sourcepub fn mbox_sha1sum(&self) -> Option<&str>
pub fn mbox_sha1sum(&self) -> Option<&str>
Return mbox_sha1sum field (hex-encoded SHA1 hash of this entity’s
mbox URI) if set; None otherwise.
Sourcepub fn openid(&self) -> Option<&UriStr>
pub fn openid(&self) -> Option<&UriStr>
Return openid field (openID URI of this entity) if set; None otherwise.
Sourcepub fn account(&self) -> Option<&Account>
pub fn account(&self) -> Option<&Account>
Return account field (reference to this entity’s Account) if set;
None otherwise.
Sourcepub fn equivalent(&self, that: &Agent) -> bool
pub fn equivalent(&self, that: &Agent) -> bool
Return TRUE if this is Equivalent to that; FALSE otherwise.