pub struct AgentBuilder { /* private fields */ }Expand description
A Type that knows how to construct an Agent.
Implementations
Sourceimpl AgentBuilder
impl AgentBuilder
Sourcepub fn with_object_type(self) -> Self
pub fn with_object_type(self) -> Self
Set objectType property.
Sourcepub fn name(self, s: &str) -> Result<Self, DataError>
pub fn name(self, s: &str) -> Result<Self, DataError>
Set the name field.
Raise DataError if the string is empty.
Sourcepub fn mbox(self, s: &str) -> Result<Self, DataError>
pub fn mbox(self, s: &str) -> Result<Self, DataError>
Set the mbox field prefixing w/ mailto: if scheme’s missing.
Built instance will have all of its other Inverse Functional Identifier
fields [re]set to None.
Raise an DataError if the string is empty, a scheme was present but
wasn’t mailto, or parsing the string as an IRI fails.
Sourcepub fn mbox_sha1sum(self, s: &str) -> Result<Self, DataError>
pub fn mbox_sha1sum(self, s: &str) -> Result<Self, DataError>
Set the mbox_sha1sum field.
Built instance will have all of its other Inverse Functional Identifier
fields [re]set to None.
Raise a DataError if the string is empty, is not 40 characters long, or contains non hexadecimal characters.
Sourcepub fn openid(self, s: &str) -> Result<Self, DataError>
pub fn openid(self, s: &str) -> Result<Self, DataError>
Set the openid field.
Built instance will have all of its other Inverse Functional Identifier
fields [re]set to None.
Raise a DataError if the string is empty, or fails parsing as a valid URI.