pub struct Attachment { /* private fields */ }Expand description
Structure representing an important piece of data that is part of a Learning Record. Could be an essay, a video, etc…
Another example could be the image of a certificate that was granted as a result of an experience.
Implementations
Sourceimpl Attachment
impl Attachment
Sourcepub fn builder() -> AttachmentBuilder<'static>
pub fn builder() -> AttachmentBuilder<'static>
Return an Attachment Builder.
Sourcepub fn usage_type(&self) -> &IriStr
pub fn usage_type(&self) -> &IriStr
Return usage_type as an IRI.
Sourcepub fn display(&self, tag: &MyLanguageTag) -> Option<&str>
pub fn display(&self, tag: &MyLanguageTag) -> Option<&str>
Return display for the given language tag if it exists; None otherwise.
Sourcepub fn display_as_map(&self) -> &LanguageMap
pub fn display_as_map(&self) -> &LanguageMap
Return a reference to display.
Sourcepub fn description(&self, tag: &MyLanguageTag) -> Option<&str>
pub fn description(&self, tag: &MyLanguageTag) -> Option<&str>
Return description for the given language tag if it exists; None
otherwise.
Sourcepub fn description_as_map(&self) -> Option<&LanguageMap>
pub fn description_as_map(&self) -> Option<&LanguageMap>
Return a reference to description if set; None otherwise.
Sourcepub fn content_type(&self) -> &Mime
pub fn content_type(&self) -> &Mime
Return content_type.
Sourcepub fn file_url_as_str(&self) -> Option<&str>
pub fn file_url_as_str(&self) -> Option<&str>
Return file_url as string reference if set; None otherwise.
Sourcepub fn set_file_url(&mut self, url: &str)
pub fn set_file_url(&mut self, url: &str)
Set the file_url field to the given value.
Sourcepub fn is_signature(&self) -> bool
pub fn is_signature(&self) -> bool
Return TRUE if this is a JWS signature; FALSE otherwise.