pub struct ContextActivities { /* private fields */ }Expand description
Map of types of learning activity context that a Statement is related to, represented as a structure (rather than the usual map).
The keys of this map, or fields of the structure are parent, grouping,
category, or other. Their corresponding values, when set, are
collections of 1 or more Activities.
Implementations
Sourceimpl ContextActivities
impl ContextActivities
Sourcepub fn builder() -> ContextActivitiesBuilder
pub fn builder() -> ContextActivitiesBuilder
Return a ContextActivities Builder.