pub struct Extensions(/* private fields */);Expand description
Extensions are available as part of Activity Definitions, as part
of a Statement’s context or result properties. In each case,
they’re intended to provide a natural way to extend those properties for
some specialized use.
The contents of these Extensions might be something valuable to just one application, or it might be a convention used by an entire Community of Practice.
From 4.2.7 Additional Requirements for Data Types / Extension:
- The LRS shall reject any Statement where a key of an extensions map is not an IRI.
- An LRS shall not reject a Statement based on the values of the extensions map.
Implementations
Sourceimpl Extensions
impl Extensions
Sourcepub fn get(&self, key: &IriStr) -> Option<&Value>
pub fn get(&self, key: &IriStr) -> Option<&Value>
Return the Value associated w/ the given key if present in this
collection; None otherwise.
Sourcepub fn contains_key(&self, key: &IriStr) -> bool
pub fn contains_key(&self, key: &IriStr) -> bool
Returns TRUE if the collection contains a value for the given key.
Return FALSE otherwise.
Sourcepub fn add(&mut self, key_str: &str, v: &Value) -> Result<(), DataError>
pub fn add(&mut self, key_str: &str, v: &Value) -> Result<(), DataError>
Add a key-value pair to this collection.
Sourcepub fn append(&mut self, other: &mut Extensions)
pub fn append(&mut self, other: &mut Extensions)
Moves all elements from other into self, leaving other empty.
If a key from other is already present in self, the respective
value from self will be overwritten with the respective value from
other.