pub struct Format { /* private fields */ }Expand description
Structure that combines a Statement resource GET request format
parameter along w/ the request’s Accept-Language, potentially empty,
list of user-preferred language-tags, in descending order of preference.
This is provided to facilitate reducing types to their canonical form
when required by higher layer APIs.
Fields included in Format variants
The next table shows for each Format variant, except exact, which fields
are included when generating a response to a GET Statement resource call.
The reason exact is not shown is b/c in that case all fields are
included.
| Entity | Field | ids | canonical |
|---|---|---|---|
| Statement | id | ✓ | ✓ |
| actor | ✓ | ✓ | |
| verb | ✓ | ✓ | |
| object | ✓ | ✓ | |
| result | ✓ | ||
| context | ✓ | ||
| timestamp | |||
| stored | |||
| authority | ✓ | ✓ | |
| version | |||
| Agent | id | ✓ | ✓ |
| ifi [1, 2] | ✓ | ✓ | |
| Group | id | ✓ | ✓ |
| ifi [1, 2] | ✓ | ✓ | |
| members | ✓ | ✓ | |
| Verb | id | ✓ | ✓ |
| display [3] | ✓ | ||
| Activity | id | ✓ | ✓ |
| definition | ✓ | ||
| ActivityDefinition | name | ✓ | |
| description | ✓ | ||
| type_ | ✓ | ||
| more_info | ✓ | ||
| interaction_type | ✓ | ||
| correct_responses_pattern | ✓ | ||
| choices | ✓ | ||
| scale | ✓ | ||
| source | ✓ | ||
| target | ✓ | ||
| steps | ✓ | ||
| extensions | ✓ | ||
| InteractionComponent | id | ✓ | |
| description | ✓ | ||
| StatementRef | id | ✓ | ✓ |
| SubStatement | actor | ✓ | ✓ |
| verb | ✓ | ✓ | |
| object | ✓ | ✓ | |
| result | ✓ | ||
| context | ✓ | ||
| timestamp |
Notes:
- The term
ifirefers to either one of the following four Inverse Functional Identifier fields:mbox,mbox_sha1sum,openidoraccount. - With
idsandcanonicalvariants, only one (1) IFI is included in the output. However, withexactall known IFIs are included. displaylike all LanguageMap instances are included incanonicalwith only one (1) language tag entry. Withexactagain all entries are included. For more information read LanguageMap Requirements
Implementations
Sourceimpl Format
impl Format
Sourcepub fn new(s: &str, tags: Vec<MyLanguageTag>) -> Result<Self, DataError>
pub fn new(s: &str, tags: Vec<MyLanguageTag>) -> Result<Self, DataError>
Return a new instance given a format string and a potentially empty list of user provided language tags expected to be in descending order of preference.
Sourcepub fn from(tags: Vec<MyLanguageTag>) -> Self
pub fn from(tags: Vec<MyLanguageTag>) -> Self
Return a new instance w/ an exact format and a potentially empty list of user provided language tags expected to be in descending order of preference.
Sourcepub fn is_canonical(&self) -> bool
pub fn is_canonical(&self) -> bool
Return TRUE if the wrapped format is the cnonical variant.
Sourcepub fn as_param(&self) -> &FormatParam
pub fn as_param(&self) -> &FormatParam
Return a reference to this format key when used as a query parameter.
Return a reference to the list of language tags provided at construction time.