pub struct Group { /* private fields */ }Expand description
Implementations
Sourceimpl Group
impl Group
Sourcepub fn from_json_obj(map: Map<String, Value>) -> Result<Self, DataError>
pub fn from_json_obj(map: Map<String, Value>) -> Result<Self, DataError>
Construct and validate a Group from a JSON Object.
Sourcepub fn builder() -> GroupBuilder
pub fn builder() -> GroupBuilder
Return a Group Builder.
Sourcepub fn check_object_type(&self) -> bool
pub fn check_object_type(&self) -> bool
Return TRUE if the objectType property is Group; FALSE otherwise.
Sourcepub fn is_anonymous(&self) -> bool
pub fn is_anonymous(&self) -> bool
Return TRUE if this Group is anonymous; FALSE otherwise.
Sourcepub fn name_as_str(&self) -> Option<&str>
pub fn name_as_str(&self) -> Option<&str>
Return name field as a string reference if set; None otherwise.
Sourcepub fn members(&self) -> Vec<&Agent>
pub fn members(&self) -> Vec<&Agent>
Return the unordered members list if it’s set or None otherwise.
When set, it’s a vector of at least one Agent). This is expected to be the case when the Group is anonymous.
Sourcepub fn mbox(&self) -> Option<&MyEmailAddress>
pub fn mbox(&self) -> Option<&MyEmailAddress>
Return mbox field if set; None otherwise.
Sourcepub fn mbox_sha1sum(&self) -> Option<&str>
pub fn mbox_sha1sum(&self) -> Option<&str>
Return mbox_sha1sum field (hex-encoded SHA1 hash of this entity’s
mbox URI) if set; None otherwise.
Sourcepub fn openid(&self) -> Option<&UriStr>
pub fn openid(&self) -> Option<&UriStr>
Return openid field (openID URI of this entity) if set; None otherwise.
Sourcepub fn account(&self) -> Option<&Account>
pub fn account(&self) -> Option<&Account>
Return account field (reference to this entity’s Account) if set;
None otherwise.
Sourcepub fn equivalent(&self, that: &Group) -> bool
pub fn equivalent(&self, that: &Group) -> bool
Return TRUE if this is Equivalent to that and FALSE otherwise.