InteractionComponent

Struct InteractionComponent 

pub struct InteractionComponent { /* private fields */ }
Depending on the value of the interactionType property of an ActivityDefinition, an Activity can provide additional properties, each potentially being a list of InteractionComponents.

Implementations

Source

impl InteractionComponent

pub fn builder() -> InteractionComponentBuilder<'static>

Return an InteractionComponent Builder.

pub fn id(&self) -> &str

Return the id field.

pub fn description(&self, tag: &MyLanguageTag) -> Option<&str>

Return description (e.g. the text for a given choice in a multiple- choice interaction) in the designated language tag if it exists; None otherwise.