pub struct InteractionComponentBuilder<'a> { /* private fields */ }Expand description
A Type that knows how to construct an InteractionComponent.
Implementations
Sourceimpl<'a> InteractionComponentBuilder<'a>
impl<'a> InteractionComponentBuilder<'a>
Sourcepub fn id(self, val: &'a str) -> Result<Self, DataError>
pub fn id(self, val: &'a str) -> Result<Self, DataError>
Set the id field.
Raise DataError if the argument is empty.
Sourcepub fn description(
self,
tag: &MyLanguageTag,
label: &str,
) -> Result<Self, DataError>
pub fn description( self, tag: &MyLanguageTag, label: &str, ) -> Result<Self, DataError>
Add label tagged by language tag to the description dictionary.
Raise DataError if an error occurred; e.g. the tag is invalid.
Sourcepub fn build(self) -> Result<InteractionComponent, DataError>
pub fn build(self) -> Result<InteractionComponent, DataError>
Create an InteractionComponent from set field values.
Raise DataError if the id field is missing.