pub struct MyDuration(/* private fields */);Expand description
Implementation of time duration that wraps Duration to better satisfy the requirements of the xAPI specifications.
Specifically, this implementation considers the patterns [PnnW] and
[PnnYnnMnnDTnnHnnMnnS] as valid.
Implementations
Sourceimpl MyDuration
impl MyDuration
Sourcepub fn new(
positive: bool,
day: u32,
second: u32,
microsecond: u32,
) -> Result<Self, DataError>
pub fn new( positive: bool, day: u32, second: u32, microsecond: u32, ) -> Result<Self, DataError>
Construct a new instance from given parameters.
Sourcepub fn truncate(&self) -> Self
pub fn truncate(&self) -> Self
Return a clone of this excluding precisions beyond 0.01 second.
Needed b/c 4.2.7 Additional Requirements for Data Types / Duration states:
When making a comparison (e.g. as a part of the statement signing process) of Statements in regard to a Duration, any precision beyond 0.01 second precision shall not be included in the comparison.
Sourcepub fn microsecond(&self) -> u32
pub fn microsecond(&self) -> u32
Return the number of microseconds, range 0 to 999999, in this.
Sourcepub fn to_iso8601(&self) -> String
pub fn to_iso8601(&self) -> String
Return this in ISO8601 format; i.e. “P9DT9H9M9.99S”