ScoreBuilder

Struct ScoreBuilder 

pub struct ScoreBuilder { /* private fields */ }
A Type that knows how to construct a Score.

Implementations

Source

impl ScoreBuilder

pub fn scaled(self, val: f32) -> Result<Self, DataError>

Set the scaled field which must be w/in [-1.0 .. +1.0] range.

pub fn raw(self, val: f32) -> Self

Set the raw field.

pub fn min(self, val: f32) -> Self

Set the min field.

pub fn max(self, val: f32) -> Self

Set the max field.

pub fn build(self) -> Result<Score, DataError>

Create a Score from set field vaues.

Raise DataError if no field was set or an inconsistency is detected.