pub struct StatementIDs(pub Vec<Uuid>);Expand description
A structure consisting of an array of Statement Identifiers (UUIDs) an LRS may return as part of a response to certain requests.
Tuple Fields
0: Vec<Uuid>Trait Implementations
Sourceimpl Debug for StatementIDs
impl Debug for StatementIDs
Sourceimpl Default for StatementIDs
impl Default for StatementIDs
Sourcefn default() -> StatementIDs
fn default() -> StatementIDs
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StatementIDs
impl<'de> Deserialize<'de> for StatementIDs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more