pub struct StatementRefBuilder { /* private fields */ }Expand description
A Type that knows how to construct a StatementRef.
Implementations
Sourceimpl StatementRefBuilder
impl StatementRefBuilder
Sourcepub fn id(self, val: &str) -> Result<Self, DataError>
pub fn id(self, val: &str) -> Result<Self, DataError>
Set the id field parsing the argument as a UUID.
Raise DataError if argument is empty, cannot be parsed into a
valid UUID, or is all zeroes (nil UUID) or ones (max UUID).
Sourcepub fn id_as_uuid(self, uuid: Uuid) -> Result<Self, DataError>
pub fn id_as_uuid(self, uuid: Uuid) -> Result<Self, DataError>
Set the identifier for this instance using the given UUID.
Raise DataError if the given UUID is all zeroes (nil UUID) or
ones (max UUID).
Sourcepub fn build(&self) -> Result<StatementRef, DataError>
pub fn build(&self) -> Result<StatementRef, DataError>
Create a StatementRef instance.
Raise a DataError if the ID field is not set.