StatementResult

Struct StatementResult 

pub struct StatementResult { /* private fields */ }
Structure that contains zero, one, or more Statements.

The statements field will contain the result of a GET Statement Resource. If it is incomplete (due for example to pagination), the rest can be accessed at the IRL provided by the more property.

Implementations

Source

impl StatementResult

pub fn from(statements: Vec<Statement>) -> Self

Construct a new instance from a given collection of Statements.

pub fn statements(&self) -> &Vec<Statement>

Return a reference to this instance’s statements collection.

pub fn is_empty(&self) -> bool

Return TRUE if the statements collection is empty.

pub fn more(&self) -> Option<&IriStr>

Return the more field of this instance if set; None otherwise.

pub fn set_more(&mut self, val: &str) -> Result<(), DataError>

Set the more field.

Raise DataError if the argument is empty, cannot be parsed as an IRI, or the resulting IRI is not a valid URL.