pub struct SubStatement { /* private fields */ }Expand description
Alternative representation of a Statement when referenced as the object of another.
Implementations
Sourceimpl SubStatement
impl SubStatement
Sourcepub fn builder() -> SubStatementBuilder
pub fn builder() -> SubStatementBuilder
Return a SubStatement Builder.
Sourcepub fn check_object_type(&self) -> bool
pub fn check_object_type(&self) -> bool
Return TRUE if the objectType property is SubStatement; FALSE
otherwise.
Sourcepub fn object(&self) -> &SubStatementObject
pub fn object(&self) -> &SubStatementObject
Sourcepub fn context(&self) -> Option<&Context>
pub fn context(&self) -> Option<&Context>
Return the Context of this instance if set; None otherwise.
Sourcepub fn timestamp(&self) -> Option<&DateTime<Utc>>
pub fn timestamp(&self) -> Option<&DateTime<Utc>>
Return timestamp of when the events described in this SubStatement
occurred if set; None otherwise.
It’s set by the LRS if not provided.
Sourcepub fn attachments(&self) -> Option<&[Attachment]>
pub fn attachments(&self) -> Option<&[Attachment]>
Return attachments if set; None otherwise.
Sourcepub fn equivalent(&self, that: &SubStatement) -> bool
pub fn equivalent(&self, that: &SubStatement) -> bool
Return TRUE if this is Equivalent to that; FALSE otherwise.