pub struct Verb { /* private fields */ }Expand description
Implementations
Sourceimpl Verb
impl Verb
Sourcepub fn builder() -> VerbBuilder<'static>
pub fn builder() -> VerbBuilder<'static>
Return a Verb Builder.
Sourcepub fn is_voided(&self) -> bool
pub fn is_voided(&self) -> bool
Return TRUE if this is the voided special verb; FALSE otherwise.
Sourcepub fn display(&self, tag: &MyLanguageTag) -> Option<&str>
pub fn display(&self, tag: &MyLanguageTag) -> Option<&str>
Sourcepub fn display_as_map(&self) -> Option<&LanguageMap>
pub fn display_as_map(&self) -> Option<&LanguageMap>
Return a reference to the display if this instance has
one; None otherwise.
Sourcepub fn equivalent(&self, that: &Verb) -> bool
pub fn equivalent(&self, that: &Verb) -> bool
Return TRUE if this is Equivalent to that; FALSE otherwise.
Sourcepub fn extend(&mut self, other: Verb) -> bool
pub fn extend(&mut self, other: Verb) -> bool
Extend this instance’s display language-map from bindings present
in other. Entries present in other but not in self are added
to the latter, while values in other with same keys will replace
current values in self.
Return TRUE if this instance was modified, FALSE otherwise.