pub struct VerbBuilder<'a> { /* private fields */ }Expand description
A Builder that knows how to construct a Verb.
Implementations
Sourceimpl<'a> VerbBuilder<'a>
impl<'a> VerbBuilder<'a>
Sourcepub fn id(self, val: &'a str) -> Result<Self, DataError>
pub fn id(self, val: &'a str) -> Result<Self, DataError>
Set the identifier of this instance.
Raise a DataError if the input string is empty or is not a valid IRI string.
Sourcepub fn display(
self,
tag: &MyLanguageTag,
label: &str,
) -> Result<Self, DataError>
pub fn display( self, tag: &MyLanguageTag, label: &str, ) -> Result<Self, DataError>
Add the given label to the display dictionary keyed by the given tag.
Raise a DataError if the tag is not a valid Language Tag.
Sourcepub fn with_display(self, map: LanguageMap) -> Result<Self, DataError>
pub fn with_display(self, map: LanguageMap) -> Result<Self, DataError>
Set (as in replace) the display property for the instance being built
w/ the one passed as argument.