pub struct XResult { /* private fields */ }Expand description
Structure capturing a quantifiable xAPI outcome.
Implementations
Sourceimpl XResult
impl XResult
Sourcepub fn builder() -> XResultBuilder
pub fn builder() -> XResultBuilder
Return an XResult Builder.
Sourcepub fn score(&self) -> Option<&Score>
pub fn score(&self) -> Option<&Score>
When set, defines the score of the participant in relation to the success or quality of an experience.
Sourcepub fn success(&self) -> Option<bool>
pub fn success(&self) -> Option<bool>
When set, defines the success or not of the participant in relation to an experience.
Sourcepub fn completion(&self) -> Option<bool>
pub fn completion(&self) -> Option<bool>
When set, defines a participant’s completion or not of an experience.
Sourcepub fn response(&self) -> Option<&str>
pub fn response(&self) -> Option<&str>
When set, defines a participant’s response to an interaction.
Sourcepub fn duration(&self) -> Option<&MyDuration>
pub fn duration(&self) -> Option<&MyDuration>
When set, defines a participant’s period of time during which the interaction occurred.
Sourcepub fn duration_to_iso8601(&self) -> Option<String>
pub fn duration_to_iso8601(&self) -> Option<String>
Return duration truncated and in ISO8601 format; i.e. “P9DT9H9M9.99S”
Sourcepub fn extensions(&self) -> Option<&Extensions>
pub fn extensions(&self) -> Option<&Extensions>
When set, defines a collection of additional free-form key/value properties associated w/ this Result.