pub enum FormatParam {
IDs,
Exact,
Canonical,
}Expand description
Possible variants for format used to represent the StatementResult
desired response to a GET Statement resource.
Variants
IDs
Only include minimum information necessary in Agent, Activity, Verb and Group Objects to identify them. For Anonymous Groups this means including the minimum information needed to identify each member.
Exact
Return Agent, Activity, Verb and Group populated exactly as they were when the Statement was received.
Canonical