pub enum InteractionType {
TrueFalse,
Choice,
FillIn,
LongFillIn,
Matching,
Performance,
Sequencing,
Likert,
Numeric,
Other,
}Expand description
Enumeration used in ActivityDefinitions.
Based on the variant used, the data formatting and purpose of other fields in an ActivityDefinition instance are implied.
Variants
TrueFalse
An interaction with two possible responses: true or false.
Format: Either true or false.
Choice
An interaction with a number of possible choices from which the learner can select. This includes interactions in which the learner can select only one answer from the list and those where the learner can select multiple items.
Format: A list of item ids delimited by [,]. If the response contains
only one item, the delimiter shall not be used.
FillIn
An interaction which requires the learner to supply a short response in the form of one or more strings of characters. Typically, the correct response consists of part of a word, one word or a few words. “Short” means that the correct responses pattern and learner response strings are normally 250 characters or less.
Format: A list of responses delimited by [,]. If the response contains only one item, the delimiter shall not be used.
LongFillIn
An interaction which requires the learner to supply a response in the form of a long string of characters. “Long” means that the correct responses pattern and learner response strings are normally more than 250 characters.
Format: A list of responses delimited by [,]. If the response contains only one item, the delimiter shall not be used.
Matching
An interaction where the learner is asked to match items in one set (the source set) to items in another set (the target set). Items do not have to pair off exactly and it is possible for multiple or zero source items to be matched to a given target and vice versa.
Format: A list of matching pairs, where each pair consists of a source
item id followed by a target item id. Items can appear in multiple
(or zero) pairs. Items within a pair are delimited by [.]. Pairs are
delimited by [,].
Performance
An interaction that requires the learner to perform a task that requires multiple steps.
Format: A list of steps containing a step ids and the response to that
step. Step ids are separated from responses by [.]. Steps are
delimited by [,]. The response can be a String as in a fill-in
interaction or a number range as in a numeric interaction.
Sequencing
An interaction where the learner is asked to order items in a set.
Format: An ordered list of item ids delimited by [,].
Likert
An interaction which asks the learner to select from a discrete set of choices on a scale.
Format: A single item id.
Numeric
Any interaction which requires a numeric response from the learner.
Format: A range of numbers represented by a minimum and a maximum delimited by [:]. Where the range does not have a maximum or does not have a minimum, that number is omitted but the delimiter is still used. E.g. [:]4 indicates a maximum for 4 and no minimum. Where the correct response or learner’s response is a single number rather than a range, the single number with no delimiter may be used.
Other
Another type of interaction that does not fit into the other variants.
Format: Any format is valid within this string as appropriate for the type of interaction.