StatementType

Enum StatementType 

pub enum StatementType {
    S(Box<Statement>),
    SId(Box<StatementId>),
    SR(StatementResult),
    SRId(StatementResultId),
}
Enumeration to allow distinguishing between different kinds of a statement collection result returned by xAPI servers.

Variants



S(Box<Statement>)

The elements are of (full) Statement.



SId(Box<StatementId>)

The elements are Statement identifiers only.



SR(StatementResult)

The elements are StatementResults.



SRId(StatementResultId)

The elements are StatementResult identifiers only.

Implementations

Source

impl StatementType

pub fn set_more(&mut self, val: &str) -> Result<(), DataError>

Set the more property of this instance.

pub fn is_empty(&self) -> bool

Return TRUE if this inner instance is a collection and is empty. Return FALSE otherwise.

pub fn stored(&self) -> DateTime<Utc>

If this inner instance is a single type, then return its stored timestamp if set or the Unix Epoch (1970-01-01 00:00:00 UTC) if it isn’t.

Alternatively, if this inner instance is a collection, then return the most recent stored timestamp of the collection’s items. If stored was not set for all the items of the collection, then return the Unix Epoch.

pub fn attachments(&self) -> Vec<Attachment>

Return the potentially empty collection of Attachments.