pub struct ActivityDefinition { /* private fields */ }Expand description
Structure that provides additional information (metadata) related to an Activity.
Implementations
Sourceimpl ActivityDefinition
impl ActivityDefinition
Sourcepub fn builder() -> ActivityDefinitionBuilder<'static>
pub fn builder() -> ActivityDefinitionBuilder<'static>
Return an ActivityDefinition Builder.
Sourcepub fn name(&self, tag: &MyLanguageTag) -> Option<&str>
pub fn name(&self, tag: &MyLanguageTag) -> Option<&str>
Return the name for the given language tag if it exists; None
otherwise.
Sourcepub fn description(&self, tag: &MyLanguageTag) -> Option<&str>
pub fn description(&self, tag: &MyLanguageTag) -> Option<&str>
Return the description for the given language tag if it exists;
None otherwise.
Sourcepub fn more_info(&self) -> Option<&IriStr>
pub fn more_info(&self) -> Option<&IriStr>
Return the more_info field if set; None otherwise.
When set, it’s an IRL that points to information about the associated Activity possibly incl. a way to launch it.
Sourcepub fn interaction_type(&self) -> Option<&InteractionType>
pub fn interaction_type(&self) -> Option<&InteractionType>
Return the interaction_type field if set; None otherwise.
Possible values are: true-false,
choice,
fill-in,
long-fill-in,
matching,
performance,
sequencing,
likert,
numeric, and
other,
Sourcepub fn correct_responses_pattern(&self) -> Option<&Vec<String>>
pub fn correct_responses_pattern(&self) -> Option<&Vec<String>>
Return the correct_responses_pattern field if set; None otherwise.
When set, it’s a Vector of patterns representing the correct response to the interaction.
The structure of the patterns vary depending on the interaction_type.
Sourcepub fn choices(&self) -> Option<&Vec<InteractionComponent>>
pub fn choices(&self) -> Option<&Vec<InteractionComponent>>
Return the choices field if set; None otherwise.
When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.
The contents of item(s) in the vector are specific to the given
interaction_type.
Sourcepub fn scale(&self) -> Option<&Vec<InteractionComponent>>
pub fn scale(&self) -> Option<&Vec<InteractionComponent>>
Return the scale field if set; None otherwise.
When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.
The contents of item(s) in the vector are specific to the given
interaction_type.
Sourcepub fn source(&self) -> Option<&Vec<InteractionComponent>>
pub fn source(&self) -> Option<&Vec<InteractionComponent>>
Return the source field if set; None otherwise.
When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.
The contents of item(s) in the vector are specific to the given
interaction_type.
Sourcepub fn target(&self) -> Option<&Vec<InteractionComponent>>
pub fn target(&self) -> Option<&Vec<InteractionComponent>>
Return the target field if set; None otherwise.
When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.
The contents of item(s) in the vector are specific to the given
interaction_type.
Sourcepub fn steps(&self) -> Option<&Vec<InteractionComponent>>
pub fn steps(&self) -> Option<&Vec<InteractionComponent>>
Return the steps field if set; None otherwise.
When set, it’s a vector of of InteractionComponents representing the correct response to the interaction.
The contents of item(s) in the vector are specific to the given
interaction_type.
Sourcepub fn extensions(&self) -> Option<&Extensions>
pub fn extensions(&self) -> Option<&Extensions>
Return the extensions field if set; None otherwise.