ActivityDefinitionBuilder

Struct ActivityDefinitionBuilder 

pub struct ActivityDefinitionBuilder<'a> { /* private fields */ }
A Type that knows how to construct an ActivityDefinition

Implementations

Source

impl<'a> ActivityDefinitionBuilder<'a>

pub fn name(self, tag: &MyLanguageTag, label: &str) -> Result<Self, DataError>

Add the given label to the name dictionary keyed by the given tag.

Raise DataError if tag is not a valid Language Tag.

pub fn description( self, tag: &MyLanguageTag, label: &str, ) -> Result<Self, DataError>

Add the given label to the description dictionary keyed by the given tag.

Raise DataError if tag is not a valid Language Tag.

pub fn type_(self, val: &'a str) -> Result<Self, DataError>

Set the type_ field.

pub fn more_info(self, val: &'a str) -> Result<Self, DataError>

Set the more_info field.

pub fn interaction_type(self, val: InteractionType) -> Self

Set the interaction_type field.

pub fn correct_responses_pattern(self, val: &str) -> Result<Self, DataError>

Add val to correct responses pattern.

pub fn choices(self, val: InteractionComponent) -> Result<Self, DataError>

Add val to choices.

pub fn scale(self, val: InteractionComponent) -> Result<Self, DataError>

Add val to scale.

pub fn source(self, val: InteractionComponent) -> Result<Self, DataError>

Add val to source.

pub fn target(self, val: InteractionComponent) -> Result<Self, DataError>

Add val to target.

pub fn steps(self, val: InteractionComponent) -> Result<Self, DataError>

Add val to steps.

pub fn extension(self, key: &str, value: &Value) -> Result<Self, DataError>

Add an extension’s key and value pair.

pub fn build(self) -> Result<ActivityDefinition, DataError>

Create an ActivityDefinition from set field values.

Raise DataError if no field was set.