Agent

Struct Agent 

pub struct Agent { /* private fields */ }
Structure that provides combined information about an individual derived from an outside service, such as a Directory Service.

Implementations

Source

impl Agent

pub fn from_json_obj(map: Map<String, Value>) -> Result<Self, DataError>

Construct and validate an Agent from a JSON Object.

pub fn builder() -> AgentBuilder

Return an Agent Builder.

pub fn check_object_type(&self) -> bool

Return TRUE if the objectType property is as expected; FALSE otherwise.

pub fn name(&self) -> Option<&CIString>

Return name if set; None otherwise.

pub fn name_as_str(&self) -> Option<&str>

Return name as a string reference if set; None otherwise.

pub fn mbox(&self) -> Option<&MyEmailAddress>

Return mbox as an MyEmailAddress if set; None otherwise.

pub fn mbox_sha1sum(&self) -> Option<&str>

Return mbox_sha1sum field (hex-encoded SHA1 hash of this entity’s mbox URI) if set; None otherwise.

pub fn openid(&self) -> Option<&UriStr>

Return openid field (openID URI of this entity) if set; None otherwise.

pub fn account(&self) -> Option<&Account>

Return account field (reference to this entity’s Account) if set; None otherwise.

pub fn uid(&self) -> u64

Return the fingerprint of this instance.

pub fn equivalent(&self, that: &Agent) -> bool

Return TRUE if this is Equivalent to that; FALSE otherwise.