pub struct Person { /* private fields */ }Expand description
Structure used in response to a GET` Agents Resource request. It
provides aggregated information about one Agent.
Also called a “Person Object” it’s very similar to an Agent, but instead of each attribute being a single value, this one has a list of them. In addition contrary to n Agent a Person may have more than of those IFI (Inverse Functional Identifier) fields populated.
Person is expected to be used, by an LRS, to associate a person-centric (aggregated) data, while an Agent only refers to one persona (one person in one context).
Implementations
Sourceimpl Person
impl Person
Sourcepub fn builder() -> PersonBuilder
pub fn builder() -> PersonBuilder
Return a Person Builder.
Sourcepub fn check_object_type(&self) -> bool
pub fn check_object_type(&self) -> bool
Return TRUE if the objectType property is as expected; FALSE otherwise.
Sourcepub fn mboxes(&self) -> &[MyEmailAddress]
pub fn mboxes(&self) -> &[MyEmailAddress]
Return the email address(es) of this Person or None if not set.
Sourcepub fn mbox_sha1sums(&self) -> &[String]
pub fn mbox_sha1sums(&self) -> &[String]
Return the email hash-sum(s) of this Person or None if not set.