StatementBuilder

Struct StatementBuilder 

pub struct StatementBuilder { /* private fields */ }
A Type that knows how to construct Statement.

Implementations

Source

impl StatementBuilder

pub fn id(self, val: &str) -> Result<Self, DataError>

Set the id field parsing the argument as a UUID.

Raise DataError if argument is empty, cannot be parsed into a valid UUID, or is all zeroes (nil UUID) or ones (max UUID).

pub fn id_as_uuid(self, uuid: Uuid) -> Result<Self, DataError>

Set the id field from given UUID.

Raise DataError if argument is empty, or is all zeroes (nil UUID) or ones (max UUID).

pub fn actor(self, val: Actor) -> Result<Self, DataError>

Set the actor field.

Raise DataError if the argument is invalid.

pub fn verb(self, val: Verb) -> Result<Self, DataError>

Set the verb field.

Raise DataError if the argument is invalid.

pub fn object(self, val: StatementObject) -> Result<Self, DataError>

Set the object field.

Raise DataError if the argument is invalid.

pub fn result(self, val: XResult) -> Result<Self, DataError>

Set the result field.

Raise DataError if the argument is invalid.

pub fn context(self, val: Context) -> Result<Self, DataError>

Set the context field.

Raise DataError if the argument is invalid.

pub fn timestamp(self, val: &str) -> Result<Self, DataError>

Set the timestamp field from a string.

Raise DataError if the argument is empty or invalid.

pub fn with_timestamp(self, val: DateTime<Utc>) -> Self

Set the timestamp field from a DateTime value.

pub fn stored(self, val: &str) -> Result<Self, DataError>

Set the stored field from a string.

Raise DataError if the argument is empty or invalid.

pub fn with_stored(self, val: DateTime<Utc>) -> Self

Set the stored field from a DateTime value.

pub fn authority(self, val: Actor) -> Result<Self, DataError>

Set the authority field.

Raise DataError if the argument is invalid.

pub fn version(self, val: &str) -> Result<Self, DataError>

Set the version field.

Raise DataError if the argument is empty or invalid.

pub fn attachment(self, att: Attachment) -> Result<Self, DataError>

Add att to attachments field if valid; otherwise raise a DataError.

pub fn build(self) -> Result<Statement, DataError>

Create a Statement from set field values.

Raise DataError if an error occurs.