pub struct StatementResult { /* private fields */ }Expand description
Structure that contains zero, one, or more Statements.
The statements field will contain the result of a GET Statement
Resource. If it is incomplete (due for example to pagination), the rest can
be accessed at the IRL provided by the more property.
Implementations
Sourceimpl StatementResult
impl StatementResult
Sourcepub fn from(statements: Vec<Statement>) -> Self
pub fn from(statements: Vec<Statement>) -> Self
Construct a new instance from a given collection of Statements.
Sourcepub fn statements(&self) -> &Vec<Statement>
pub fn statements(&self) -> &Vec<Statement>
Return a reference to this instance’s statements collection.