VerbBuilder

Struct VerbBuilder 

pub struct VerbBuilder<'a> { /* private fields */ }
A Builder that knows how to construct a Verb.

Implementations

Source

impl<'a> VerbBuilder<'a>

pub fn id(self, val: &'a str) -> Result<Self, DataError>

Set the identifier of this instance.

Raise a DataError if the input string is empty or is not a valid IRI string.

pub fn display( self, tag: &MyLanguageTag, label: &str, ) -> Result<Self, DataError>

Add the given label to the display dictionary keyed by the given tag.

Raise a DataError if the tag is not a valid Language Tag.

pub fn with_display(self, map: LanguageMap) -> Result<Self, DataError>

Set (as in replace) the display property for the instance being built w/ the one passed as argument.

pub fn build(self) -> Result<Verb, DataError>

Create a Verb instance.

Raise DataError if the definition (id) field is not set or is an invalid IRI.